# Tests the HeatRateRadiationRZ post-processor.

R_o = 0.2
thickness = 0.05
R_i = ${fparse R_o - thickness}

L = 3.0
S = ${fparse 2 * pi * R_o * L}

Q = 5000
T = 300
T_ambient = 350
sigma = 5.670367e-8
emissivity = ${fparse Q / (S * sigma * (T_ambient^4 - T^4))}

[SolidProperties]
  [region1-mat]
    type = ThermalFunctionSolidProperties
    k = 1
    cp = 1
    rho = 1
  []
[]

[Components]
  [heat_structure]
    type = HeatStructureCylindrical

    position = '1 2 3'
    orientation = '1 1 1'
    inner_radius = ${R_i}
    length = ${L}
    n_elems = 50

    names = 'region1'
    solid_properties = 'region1-mat'
    solid_properties_T_ref = '300'
    widths = '${thickness}'
    n_part_elems = '5'

    initial_T = ${T}
  []
[]

[Postprocessors]
  [Q_pp]
    type = HeatRateRadiationRZ
    boundary = heat_structure:outer
    axis_point = '1 2 3'
    axis_dir = '1 1 1'
    T = T_solid
    T_ambient = ${T_ambient}
    emissivity = ${emissivity}
    stefan_boltzmann_constant = ${sigma}
    execute_on = 'initial'
  []
[]

[Problem]
  solve = false
[]

[Executioner]
  type = Transient
  num_steps = 1
[]

[Outputs]
  file_base = 'heat_rate_radiation_rz'
  [csv]
    type = CSV
    precision = 15
    execute_on = 'initial'
  []
[]
